@@ -167,6 +167,36 @@ class Ec2InstanceWrapper(object):
             raise LookupError('Did not get exactly one instance with tag:Name={0}'.format(name))
         return cls(reservation.instances[0])
 
+    @classmethod
+    def get_by_tagvalue(cls, tags={}, region=None):
+        """
+        Connect to AWS and get the EC2 instance with the given tag:value pairs.
+
+        :param tags
+            A string like 'role=testing,fake=yes' to AND a set of ec2 
+            instance tags
+        :param region:
+            optional.
+        :raise Ec2RegionConnectionError: If connecting to the region fails.
+        :raise LookupError: If no matching instance was found in the region.
+        :return: A list of :class:`Ec2InstanceWrapper`s containing the 
+            matching instances.
+        """
+        region = region is None and awsfab_settings.DEFAULT_REGION or region
+        connection = connect_to_region(region_name=region, **awsfab_settings.AUTH)
+        if not connection:
+            raise Ec2RegionConnectionError(region)
+        tags = dict((('tag:%s' % oldk, v) for (oldk, v) in tags.iteritems()))
+        reservations = connection.get_all_instances(filters=tags)
+        if len(reservations) == 0:
+            raise LookupError('No ec2 instances with tags{0}'.format(tags))
+        insts = []
+        for r in reservations:
+            for instance in r.instances:
+                insts.append(cls(instance))
+        return insts
+
+
     @classmethod
     def get_by_instanceid(cls, instanceid):
         """
@@ -278,3 +308,37 @@ def print_ec2_instance(instance, full=False, indentspaces=3):
         if not isinstance(value, (str, unicode, bool, int)):
             value = pformat(value)
         print '{indent}{attrname}: {value}'.format(**vars())
+
+
+
+
+hostsfile_template = """
+127.0.0.1 localhost
+
+# The following lines are desirable for IPv6 capable hosts
+::1 ip6-localhost ip6-loopback
+fe00::0 ip6-localnet
+ff00::0 ip6-mcastprefix
+ff02::1 ip6-allnodes
+ff02::2 ip6-allrouters
+ff02::3 ip6-allhosts
+
+{custom_hosts}
+"""
+
+def _nametags_to_hostslist(nametags=[], suffix='.ec2private'):
+    hostslist = []
+    for nametag in nametags:
+        instancewrapper = Ec2InstanceWrapper.get_by_nametag(nametag)
+        private_ip_address = instancewrapper.instance.private_ip_address
+        hostslist.append('{private_ip_address} {nametag}{suffix}'.format(**vars()))
+    return hostslist
+
+def create_hostsfile_from_nametags(nametags=[], suffix='.ec2private', hostsfile_template=hostsfile_template):
+    """
+    Create a ``/etc/hosts`` file from the list of ``nametags``.
+    The result will be a hostsfile with private_ip_address as IP, and
+    ``nametag+suffix`` as hostname.
+    """
+    hostslist = _nametags_to_hostslist(nametags, suffix)
+    return hostsfile_template.format(custom_hosts='\n'.join(hostslist))
